@@ -2,7 +2,7 @@
 # @Author: Anderson
 # @Date:   2019-11-11 17:42:18
 # @Last Modified by:   ander
-# @Last Modified time: 2020-05-26 11:51:18
+# @Last Modified time: 2020-11-21 19:18:19
 from openpyxl import Workbook, load_workbook
 from docx import Document
 import requests
@@ -47,6 +47,8 @@ class WebCrawlerBot(object):
 		}
 		self.weibo_hot_list = []
 		self.liepin_urls = {}
+		self.抓取猎聘 = self.get_liepin
+		self.抓取论文 = self.get_arxiv
 
 	def set_cookie(self, cookie):
 		self.headers['cookie'] = cookie
@@ -93,7 +95,7 @@ class WebCrawlerBot(object):
 		content = soup.select(".card-wrap .content .txt")[0].text.strip()
 		return [hot_count, title, author, content, url]
 
-	def get_liepin(self, keyword, page):
+	def get_liepin(self, keyword, start_page, end_page=None):
 		if keyword not in self.liepin_urls:
 			req = requests.get(
 				f'https://www.liepin.com/zhaopin/?sfrom=click-pc_homepage-centre_searchbox-search_new&d_sfrom=search_fp&key={quote_plus(keyword)}',
@@ -102,34 +104,37 @@ class WebCrawlerBot(object):
 			self.liepin_urls[keyword] = 'https://www.liepin.com'
 			self.liepin_urls[keyword] += '&d_curPage={d_curPage}'.join(soup.select('.pagerbar a')[3]['href'].split('&d_curPage='))
 			self.liepin_urls[keyword] = self.liepin_urls[keyword].split('&curPage=')[0] + '&curPage={curPage}'
-		if page > 0:
-			url = self.liepin_urls[keyword].format(d_curPage=page - 1, curPage=page)
-		else:
-			url = self.liepin_urls[keyword].format(d_curPage=page + 1, curPage=page)
-		req = requests.get(url, headers=self.headers)
-		soup = BeautifulSoup(req.text, 'lxml')
+		if end_page is None:
+			end_page = start_page + 1
 		results = []
-		for item in soup.select('.sojob-item-main'):
-			job_name = item.select('h3 a')[0].text.strip()
-			job_company = item.select('.company-name')[0].text.strip()
-			job_field = item.select('.field-financing')[0].text.strip()
-			job_salary = item.select('.condition .text-warning')[0].text.strip()
-			if job_salary == '面议':
-				annual_salary = -1
+		for page in range(start_page, end_page):
+			if page > 0:
+				url = self.liepin_urls[keyword].format(d_curPage=page - 1, curPage=page)
 			else:
-				if '-' in job_salary:
-					min_salary = int(job_salary[:job_salary.index('-')])
-					max_salary = int(job_salary[job_salary.index('-') + 1:job_salary.index('k')])
-					months = int(job_salary[job_salary.index('·') + 1:-1])
-					annual_salary = (min_salary + max_salary) / 2 * months * 1000
+				url = self.liepin_urls[keyword].format(d_curPage=page + 1, curPage=page)
+			req = requests.get(url, headers=self.headers)
+			soup = BeautifulSoup(req.text, 'lxml')
+			for item in soup.select('.sojob-item-main'):
+				job_name = item.select('h3 a')[0].text.strip()
+				job_company = item.select('.company-name')[0].text.strip()
+				job_field = item.select('.field-financing')[0].text.strip()
+				job_salary = item.select('.condition .text-warning')[0].text.strip()
+				if job_salary == '面议':
+					annual_salary = -1
 				else:
-					monthly_salary = int(job_salary.split('k')[0])
-					months = int(job_salary[job_salary.index('·') + 1:-1])
-					annual_salary = monthly_salary * months * 1000
-			job_area = item.select('.condition .area')[0].text.strip()
-			job_edu = item.select('.condition .edu')[0].text.strip()
-			job_experience = item.select('.condition span')[-1].text.strip()
-			results.append([job_name, job_company, job_field, job_salary, annual_salary, job_area, job_edu, job_experience])
+					if '-' in job_salary:
+						min_salary = int(job_salary[:job_salary.index('-')])
+						max_salary = int(job_salary[job_salary.index('-') + 1:job_salary.index('k')])
+						months = int(job_salary[job_salary.index('·') + 1:-1])
+						annual_salary = (min_salary + max_salary) / 2 * months * 1000
+					else:
+						monthly_salary = int(job_salary.split('k')[0])
+						months = int(job_salary[job_salary.index('·') + 1:-1])
+						annual_salary = monthly_salary * months * 1000
+				job_area = item.select('.condition .area')[0].text.strip()
+				job_edu = item.select('.condition .edu')[0].text.strip()
+				job_experience = item.select('.condition span')[-1].text.strip()
+				results.append([job_name, job_company, job_field, job_salary, annual_salary, job_area, job_edu, job_experience])
 		return results
 
 	def get_huaban(self, keyword, page, key='k4rwsxf5'):
@@ -183,6 +188,18 @@ class ExcelBot(object):
 	def __init__(self):
 		self.workbook = Workbook()
 		self.sheet = self.workbook.active
+		self.添加数据 = self.add_data
+		self.添加一行数据 = self.add_row
+		self.提取一行数据 = self.get_row
+		self.提取一列数据 = self.get_col
+		self.保存文件 = self.save
+
+	def add_data(self, data):
+		try:
+			for row in data:
+				self.add_row(row)
+		except Exception as e:
+			print(e)
 
 	def add_row(self, row):
 		try:
@@ -219,7 +236,7 @@ class ExcelBot(object):
 		if filename.endswith('.csv'):
 			self.workbook = Workbook()
 			self.sheet = self.workbook.active
-			with open(filename) as f:
+			with open(filename, encoding='utf-8') as f:
 				reader = csv.reader(f)
 				for row in reader:
 					self.sheet.append(row)
@@ -307,6 +324,8 @@ class DataAnalysisBot(object):
 	"""docstring for DataAnalysisBot"""
 	def __init__(self):
 		self.data = []
+		self.分析词语频次 = self.get_word_frequency
+		self.生成词云图 = self.generate_word_cloud
 
 	def set_data(self, data):
 		self.data = copy(data)
@@ -406,8 +425,8 @@ class DataAnalysisBot(object):
 		map_3d.render("map3d_with_bar3d.html")
 
 
-pachong = wc_bot = web_crawler_bot = WebCrawlerBot()
-biaoge = ec_bot = excel_bot = ExcelBot()
-shuju = da_bot = data_analysis_bot = DataAnalysisBot()
-pdf_bot = PDFBot()
-word_bot = WordBot()
+爬虫机器人 = pachong = wc_bot = web_crawler_bot = WebCrawlerBot()
+表格机器人 = biaoge = ec_bot = excel_bot = ExcelBot()
+数据机器人 = shuju = da_bot = data_analysis_bot = DataAnalysisBot()
+PDF机器人 = pdf_bot = PDFBot()
+文档机器人 = word_bot = WordBot()
